@@ -97,7 +97,10 @@ create_hildon_actor(Actor *actor, AWallpaperPlugin *desktop_plugin)
   gchar     *str = NULL;
 
   ha = hildon_animation_actor_new();
-  str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
+  if (!strcmp(actor->name, "original"))
+      str = g_strdup(actor->filename);
+  else 
+      str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
                         desktop_plugin->priv->theme, actor->filename);
   pixbuf = gdk_pixbuf_new_from_file_at_size (str, 
                                              actor->width, 
