@@ -30,7 +30,8 @@
 #define GCONF_KEY_PREFIX                            "/apps/maemo/livewp"
 #define GCONF_KEY_THEME                             GCONF_KEY_PREFIX"/theme"
 #define GCONF_KEY_RANIMATION                        GCONF_KEY_PREFIX"/rich_animation"
-#define GCONF_KEY_ADDIONAL_STRING_1                  GCONF_KEY_PREFIX"/additional_string_1"
+#define GCONF_KEY_ADDITIONAL_STRING_1                  GCONF_KEY_PREFIX"/additional_string_1"
+#define GCONF_KEY_ADDITIONAL_BOOL_1                  GCONF_KEY_PREFIX"/additional_bool_1"
 void init_scene_Modern(AWallpaperPlugin *desktop_plugin);
 void init_scene_Berlin(AWallpaperPlugin *desktop_plugin);
 void init_scene_Matrix(AWallpaperPlugin *desktop_plugin);
