@@ -31,11 +31,11 @@
 /*******************************************************************************/
 void livewp_initialize_dbus(Animation_WallpaperPrivate *priv);
 void livewp_deinitialize_dbus(Animation_WallpaperPrivate *priv);
-DBusHandlerResult
-get_livewp_signal_cb(DBusConnection *conn, DBusMessage *msg, Animation_WallpaperPrivate *priv);
-
+DBusHandlerResult get_livewp_signal_cb(DBusConnection *conn, DBusMessage *msg, Animation_WallpaperPrivate *priv);
 void send_dbus_signal (Animation_WallpaperPrivate *priv, const gchar *interface, const gchar *path, const gchar *member);
 gint read_config(Animation_WallpaperPrivate *priv);
 void reload_scene(AWallpaperPlugin *desktop_plugin);
+void quit_from_program (Animation_WallpaperPrivate *priv);
+void view_state_changed (Animation_WallpaperPrivate *priv);
 /*******************************************************************************/
 #endif
