@@ -65,20 +65,15 @@ GType animation_wallpaper_plugin_get_type(void);
 Animation_WallpaperPrivate* animation_wallpaper_plugin_new (void);
 G_END_DECLS
 void lw_settings(gpointer user_data, gpointer data);
-//void actor_set_position_full(GtkWidget *actor, gint x, gint y, gint z);
 gint read_config(Animation_WallpaperPrivate *priv);
 void save_config(Animation_WallpaperPrivate *priv);
-void run_long_timeout(AWallpaperPlugin *desktop_plugin);
-//void set_actor_visible(Actor *actor, gboolean visible);
-//void set_actor_scale(Actor *actor, double scalex, double scaley);
-void create_hildon_actor(Actor *actor, AWallpaperPlugin *desktop_plugin);
-void create_hildon_actor_text(Actor *actor, AWallpaperPlugin *desktop_plugin); 
+//void run_long_timeout(AWallpaperPlugin *desktop_plugin);
 void get_sun_screen_pos(double alt, double azm, gint * x, gint * y);
 void show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
 void livewp_initialize_dbus(Animation_WallpaperPrivate *priv);
 void livewp_deinitialize_dbus(Animation_WallpaperPrivate *priv);
 gint current_active_view(void);
-gboolean long_timeout (AWallpaperPlugin *desktop_plugin);
+//gboolean long_timeout (AWallpaperPlugin *desktop_plugin);
 void desktop_plugin_visible_notify (GObject *object, GParamSpec *spec, AWallpaperPlugin *desktop_plugin);
 void send_dbus_signal (Animation_WallpaperPrivate *priv, const gchar *interface, const gchar *path, const gchar *member);
 
